==> gjs-1.56.2.tar.xz: gjs-1.56.2/libgjs-private/gjs-gtk-util.h <==
/* -*- mode: C; c-basic-offset: 4; indent-tabs-mode: nil; -*- */
/* Copyright 2014 Endless Mobile, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

#ifndef __GJS_PRIVATE_GTK_UTIL_H__
#define __GJS_PRIVATE_GTK_UTIL_H__

#include "config.h"

#ifdef ENABLE_GTK

#include <gtk/gtk.h>

#include <gjs/macros.h>

G_BEGIN_DECLS

GJS_EXPORT
void gjs_gtk_container_child_set_property (GtkContainer *container,
                                           GtkWidget    *child,
                                           const gchar  *property,
                                           const GValue *value);

G_END_DECLS

#endif

#endif /* __GJS_PRIVATE_GTK_UTIL_H__ */

==> gjs-1.57.4.tar.xz: gjs-1.57.4/libgjs-private/gjs-gtk-util.h <==
/* -*- mode: C; c-basic-offset: 4; indent-tabs-mode: nil; -*- */
/* Copyright 2014 Endless Mobile, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

#ifndef LIBGJS_PRIVATE_GJS_GTK_UTIL_H_
#define LIBGJS_PRIVATE_GJS_GTK_UTIL_H_

#include <config.h> /* for ENABLE_GTK */

#ifdef ENABLE_GTK

#    include <glib-object.h>
#    include <glib.h>
#    include <gtk/gtk.h>

#    include "gjs/macros.h"

G_BEGIN_DECLS

GJS_EXPORT
void gjs_gtk_container_child_set_property (GtkContainer *container,
                                           GtkWidget    *child,
                                           const gchar  *property,
                                           const GValue *value);

G_END_DECLS

#endif

#endif /* LIBGJS_PRIVATE_GJS_GTK_UTIL_H_ */
